@@ -4,12 +4,12 @@ use warnings;
 use Tk;
 use Tk::Chart::Bars;
 
-my $mw = new MainWindow(
+my $mw = MainWindow->new(
   -title      => 'Tk::Chart::Bars - overwrite',
   -background => 'white',
 );
 
-my $Chart = $mw->Bars(
+my $chart = $mw->Bars(
   -title      => 'Tk::Chart::Bars - overwrite',
   -xlabel     => 'X Label',
   -ylabel     => 'Y Label',
@@ -26,17 +26,17 @@ my @data = (
 );
 
 # Add a legend to the graph
-my @Legends = ( 'legend 1', 'legend 2', );
-$Chart->set_legend(
+my @legends = ( 'legend 1', 'legend 2', );
+$chart->set_legend(
   -title       => 'Title legend',
-  -data        => \@Legends,
+  -data        => \@legends,
   -titlecolors => 'blue',
 );
 
 # Add help identification
-$Chart->set_balloon();
+$chart->set_balloon();
 
 # Create the graph
-$Chart->plot( \@data );
+$chart->plot( \@data );
 
 MainLoop();
